@@ -147,6 +147,7 @@ class ExportUtil
                 return 'Array &' . $key;
             }
 
+            \assert(\is_array($value));
             $array  = $value;
             $key    = $processed->add($value);
             $values = '';
@@ -171,10 +172,12 @@ class ExportUtil
             $class = get_class($value);
 
             if ($processed->contains($value)) {
+                \assert(\is_object($value));
                 return sprintf('%s#%d Object', $class, spl_object_id($value));
             }
 
             $processed->add($value);
+            \assert(\is_object($value));
             $values = '';
             $array  = self::toArray($value);
 
